# archive_spec.py
#
# Project: AutoArchive
# License: GNU GPLv3
#
# Copyright (C) 2003 - 2009 Robert Cernansky
# Copyright (C) 2003 - 2009 HOME software



"""Access to archive spec files.
"""



# INCLUDE FILES

import re
import glob
import ConfigParser

from aautils import *



# CLASSES

class ArchiveSpec(object):
    "Represents files for archiving."

    def __init__(self, specFile):

        # read .aa file
        spec = ConfigParser.SafeConfigParser()
        spec.readfp(open(specFile))

        # file name and path
        self.name = spec.get("General", "name")
        self.path = os.path.expanduser(spec.get("General", "path"))

        # extract filenames from specFile and store them into list
        self.__includes = re.findall(r'(?:".+?")|(?:\S+)',
                                     spec.get("General", "include_files"))
        self.__excludes = re.findall(r'(?:".+?")|(?:\S+)',
                                     spec.get("General", "exclude_files"))

        # previous regexp leaves quotes in filenames so they must be removed
        self.__includes = self.__clearQuotes(self.__includes)
        self.__excludes = self.__clearQuotes(self.__excludes)



    def __getIncludes(self):
        return self.__includes

    includes = property(__getIncludes, doc =
                        "Gets list of files and directories for archiving.")



    def __getExcludes(self):
        return self.__excludes

    excludes = property(__getExcludes, doc =
                        "Gets list of files and directories excluded from " +
                        "archiving.")



    def __getIncludesExpanded(self):
        
        return self.__expandWilds(self.includes)

    includesExpanded = property(__getIncludesExpanded, doc =
                                "Gets list of wildcard expanded files and " +
                                "directories for archiving.")



    def __getExcludesExpanded(self):
        return self.__expandWilds(self.excludes)

    excludesExpanded = property(__getExcludesExpanded, doc =
                                "Gets list of wildcard expanded files and " +
                                "directories excluded from archiving.")



    def __expandWilds(self, files):
        "Expand wildchars in list of files."

        cwdSave = os.getcwd()
        os.chdir(self.path)

        expandedFiles = []
        for fileName in files:
            expanded = glob.glob(fileName)
            if expanded:
                expandedFiles.extend(expanded)
            else:
                printError(fileName + ": No such file or directory")

        os.chdir(cwdSave)
        return expandedFiles



    def __clearQuotes(self, files):
        "Remove quotes from filenames."

        cleanFiles = []
        for fileName in files:
            match = re.search('(?<=").+(?=")', fileName)
            if match != None:
                cleanFiles.append(match.group(0))
            else:
                cleanFiles.append(fileName)
        return cleanFiles
